@@ -26,8 +26,11 @@
 
 namespace LibreNMS\Tests\Feature\SnmpTraps;
 
+use PHPUnit\Framework\Attributes\TestDox;
+
 final class AdvaAttributeChangeTest extends SnmpTrapTestCase
 {
+    #[TestDox('Syslog IP version modified')]
     public function testSyslogIPVersionModified(): void
     {
         $this->assertTrapLogsMessage(<<<'TRAP'
@@ -45,6 +48,7 @@ TRAP,
         );
     }
 
+    #[TestDox('Syslog IPv6 addr modified')]
     public function testSyslogIP6AddrModified(): void
     {
         $this->assertTrapLogsMessage(<<<'TRAP'
@@ -62,6 +66,7 @@ TRAP,
         );
     }
 
+    #[TestDox('Syslog IP addr modified')]
     public function testSyslogIPAddrModified(): void
     {
         $this->assertTrapLogsMessage(<<<'TRAP'
